@@ -49,7 +49,7 @@ def get_item(key_dict, table_name, dynamodb):
   '''
   try:
     table = dynamodb.Table(table_name)
-    return table.get_item(Key=key_dict)['Item']
+    return table.get_item(Key=key_dict).get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
 
@@ -64,7 +64,7 @@ def get_item_and_retrieve_specific_attributes(key_dict, attr_list, table_name, d
   '''
   try:
     table = dynamodb.Table(table_name)
-    return table.get_item(Key=key_dict, AttributesToGet=attr_list)['Item']
+    return table.get_item(Key=key_dict, AttributesToGet=attr_list).get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
 
@@ -158,7 +158,7 @@ def query_by_key(key_condition, table_name, dynamodb):
     table = dynamodb.Table(table_name)
     return table.query(
       KeyConditionExpression=key_condition
-    )['Item']
+    ).get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
 
@@ -175,7 +175,7 @@ def query_and_project_by_key_condition(projection_expr, expr_attr_names, key_con
       KeyConditionExpression = key_condition,
       ProjectionExpression = projection_expr,
       ExpressionAttributeNames = expr_attr_names
-    )['Items']
+    ).get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
 
@@ -218,13 +218,13 @@ def query_by_key_min_max(key_condition, table_name, is_min, dynamodb):
       KeyConditionExpression=key_condition,
       ScanIndexForward = is_min,
       Limit = 1
-    )['Items']
+    ).get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
 
 def get_all_items_in_table(table_name, dynamodb):
   try:
     table = dynamodb.Table(table_name)
-    return table.scan()['Items']
+    return table.scan().get('Item', None)
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
\ No newline at end of file
